@@ -1,10 +1,15 @@
 import numpy
 import torch
 
+__version__ = "0.0.6"
+
 
 # This is expected to be safe, although in PyTorch 1.7 it comes as a warning,
 # if CUDA is not installed.
-DEVICE = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
+try:
+    DEVICE = torch.device("cuda:0" if torch.cuda.is_available() else "cpu")
+except Exception:
+    DEVICE = torch.device("cpu")
 
 
 def to_list(e):
